@@ -3,14 +3,15 @@ import tkinter as tk
 from tkinter import ttk
 
 import sv_ttk
-from data import __video_directory__
-from scraper import subscene_soup
-from utils import file_manager
-
-from . import tkinter_data as tkd
-from . import widget_root
 
+from subsearch.data import __video_directory__
+from subsearch.gui import tkdata, widget_root
+from subsearch.scraper import subscene_soup
+from subsearch.utils import file_manager
 
+TKWINDOW = tkdata.Window()
+TKCOLOR = tkdata.Color()
+TKFONT = tkdata.Font()
 # file with subtitles and corresponding dl links
 def read_tmp_file():
     file = os.path.join(__video_directory__, "__subsearch__dl_data.tmp")
@@ -25,13 +26,12 @@ class DownloadList(tk.Frame):
         # listbox for the subtitles
         self.extent = 0
         self.sublist = read_tmp_file()
-        self.sublist_lenght = len(self.sublist)
         self.hs = ttk.Scrollbar(root, orient="vertical", style="Vertical.TScrollbar")
         sub_listbox = tk.Listbox(
             root,
-            bg=tkd.Color.dark_grey,
-            fg=tkd.Color.light_grey,
-            font=tkd.Font.cas8b,
+            bg=TKCOLOR.dark_grey,
+            fg=TKCOLOR.light_grey,
+            font=TKFONT.cas8b,
             bd=0,
             border=0,
             borderwidth=0,
@@ -39,14 +39,13 @@ class DownloadList(tk.Frame):
             yscrollcommand=self.hs.set,
         )
         sub_listbox.place(
-            height=tkd.Window.height - 60,
-            width=tkd.Window.width - 20,
+            height=TKWINDOW.height - 60,
+            width=TKWINDOW.width - 20,
             relx=0.5,
             rely=0.525,
             bordermode="inside",
             anchor="center",
         )
-        self.count = 0
         self.sub_listbox = sub_listbox
         self.fill_listbox()
         # custom scrollbar
@@ -67,7 +66,7 @@ class DownloadList(tk.Frame):
             arrowsize=24,
         )
 
-        self.hs.place(x=tkd.Window.width - 28, y=51, bordermode="inside", height=633)
+        self.hs.place(x=TKWINDOW.width - 28, y=51, bordermode="inside", height=633)
         self.hs.config(command=self.sub_listbox.yview)
         self.hs.lift()
 
@@ -75,19 +74,18 @@ class DownloadList(tk.Frame):
         dicts_names = {}
         dicts_urls = {}
         # fil list box with all available subtitles that were found and not downloaded
-        for x, i in zip(range(0, self.sublist_lenght), self.sublist):
-            x = i.split(" ")
+        for enu, item in enumerate(self.sublist):
+            x = item.split(" ")
             match = f"{x[0]} {x[1]}"
             name = x[2]
             url = x[-1]
             txt = f"{match} {name}"
             self.sub_listbox.insert(tk.END, f"{match} {name}\n")
             self.sub_listbox.bind("<ButtonPress-1>", self.mouse_b1_press)
-            dicts_names[self.count] = txt
-            dicts_urls[self.count] = url
+            dicts_names[enu] = txt
+            dicts_urls[enu] = url
             self.dicts_urls = dicts_urls
             self.dicts_names = dicts_names
-            self.count += 1
 
     def mouse_b1_press(self, event):
         self.sub_listbox.bind("<<ListboxSelect>>", self.download_button)
@@ -107,7 +105,7 @@ class DownloadList(tk.Frame):
             if number == int(items):
                 self.sub_listbox.delete(int(number))
                 self.sub_listbox.insert(int(number), f"»»» DOWNLOADING «««")
-                self.sub_listbox.itemconfig(int(number), {"fg": tkd.Color.blue})
+                self.sub_listbox.itemconfig(int(number), {"fg": TKCOLOR.blue})
                 try:
                     dl_url = subscene_soup.get_download_url(url)
                     _name = name.replace("/", "").replace("\\", "").split(": ")
@@ -120,13 +118,13 @@ class DownloadList(tk.Frame):
                         file_manager.clean_up(__video_directory__, ").nfo")
                         self.sub_listbox.delete(int(number))
                         self.sub_listbox.insert(int(number), f"✔ {name}")
-                        self.sub_listbox.itemconfig(int(number), {"fg": tkd.Color.green})
+                        self.sub_listbox.itemconfig(int(number), {"fg": TKCOLOR.green})
                         _error = False
                 except OSError:
                     _error = True
                     self.sub_listbox.delete(int(number))
                     self.sub_listbox.insert(int(number), f"⚠⚠⚠ Download failed ⚠⚠⚠")
-                    self.sub_listbox.itemconfig(int(number), {"fg": tkd.Color.red})
+                    self.sub_listbox.itemconfig(int(number), {"fg": TKCOLOR.red})
 
 
 def show_widget():
@@ -134,5 +132,5 @@ def show_widget():
     root = widget_root.main()
     sv_ttk.set_theme("dark")
     DownloadList(root).pack(anchor="center")
-    tk.Frame(root, bg=tkd.Color.dark_grey).pack(anchor="center", expand=True)
+    tk.Frame(root, bg=TKCOLOR.dark_grey).pack(anchor="center", expand=True)
     root.mainloop()
