@@ -2,16 +2,16 @@ import os
 import shutil
 import struct
 import zipfile
+from typing import Any, Optional
 
 import cloudscraper
 
-from . import log, string_parser
+from subsearch.utils import log, string_parser
 
 SCRAPER = cloudscraper.create_scraper(browser={"browser": "chrome", "platform": "android", "desktop": False})
 
 
-# download zip files from url
-def download_zip(item: str) -> None:
+def download_zip(item: Any) -> None:
     """
     download zip file from url
 
@@ -41,9 +41,8 @@ def extract_zips(cwd: str, extension: str) -> None:
     for file in os.listdir(cwd):
         if file.startswith("__subsearch__") and file.endswith(extension):
             log.output(f"Extracting: {file} -> ..\\subs\\{file}")
-            file_name = os.path.join(cwd, file)
-            # file_name = os.path.abspath(file)
-            zip_ref = zipfile.ZipFile(file_name)
+            filename = os.path.join(cwd, file)
+            zip_ref = zipfile.ZipFile(filename)
             zip_ref.extractall(subs_folder)
             zip_ref.close()
 
@@ -62,19 +61,20 @@ def rename_best_match(release_name: str, cwd: str, extension: str) -> None:
     subs_folder = os.path.join(cwd, "subs")
     for file in os.listdir(subs_folder):
         if file.endswith(extension):
-            value = string_parser.pct_value(file, release_name)
+            value = string_parser.get_pct_value(file, release_name)
             if value >= higest_value[0]:
                 higest_value = value, file
 
     file_to_rename = higest_value[1]
-    old_name_src = os.path.join(subs_folder, file_to_rename)
-    new_name_dst = os.path.join(subs_folder, release_name)
-    log.output(f"Renaming: {file} -> {release_name}")
-    os.rename(old_name_src, new_name_dst)
-    move_src = new_name_dst
-    move_dst = os.path.join(cwd, release_name)
-    log.output(f"Moving: {release_name} -> {cwd}")
-    shutil.move(move_src, move_dst)
+    if file_to_rename.endswith(extension):
+        old_name_src = os.path.join(subs_folder, file_to_rename)
+        new_name_dst = os.path.join(subs_folder, release_name)
+        log.output(f"Renaming: {file_to_rename } -> {release_name}")
+        os.rename(old_name_src, new_name_dst)
+        move_src = new_name_dst
+        move_dst = os.path.join(cwd, release_name)
+        log.output(f"Moving: {release_name} -> {cwd}")
+        shutil.move(move_src, move_dst)
 
 
 # remove .zips
@@ -94,21 +94,21 @@ def clean_up(cwd: str, extension: str) -> None:
 
 
 # get file hash
-def get_hash(file_name: str) -> str | None:
+def get_hash(file_path: str) -> Optional[str]:
     """
     Tries to get the hash of the file
 
     Args:
-        file_name (str): path/file_name to get the hash of
+        file_path (str): path/filename to get the hash of
 
     Returns:
-        str | None: the hash of the file or None if the size is 0
+        str | Any: the hash of the file or None if the size is 0
     """
     try:
         longlongformat = "<q"  # little-endian long long
         bytesize = struct.calcsize(longlongformat)
-        with open(file_name, "rb") as f:
-            filesize = os.path.getsize(file_name)
+        with open(file_path, "rb") as f:
+            filesize = os.path.getsize(file_path)
             hash = filesize
             if filesize < 65536 * 2:
                 log.output(f"SizeError: filesize is {filesize} bytes", False)
@@ -130,5 +130,6 @@ def get_hash(file_name: str) -> str | None:
         returnedhash = "%016x" % hash
         return returnedhash
 
-    except IOError as err:
-        return log.output(err)
+    except IOError:
+        log.output("IOError")
+        return None
