@@ -2,16 +2,16 @@ import os
 import socket
 import sys
 import winreg
+from typing import Literal
 
-from data import __icons__, __root__
-
-from . import current_user
+from subsearch.data import __icons__, __root__
+from subsearch.utils import current_user
 
 COMPUTER_NAME = socket.gethostname()
-ASTERISK_PATH = r"Software\Classes\*"
-SHELL_PATH = r"Software\Classes\*\shell"
-SUBSEARCH_PATH = r"Software\Classes\*\shell\0.SubSearch"
-COMMAND_PATH = r"Software\Classes\*\shell\0.SubSearch\command"
+ASTERISK_PATH = "Software\\Classes\\*"
+SHELL_PATH = "Software\\Classes\\*\\shell"
+SUBSEARCH_PATH = "Software\\Classes\\*\\shell\\0.SubSearch"
+COMMAND_PATH = "Software\\Classes\\*\\shell\\0.SubSearch\\command"
 
 
 def write_keys() -> None:
@@ -44,7 +44,7 @@ def write_valuex(key: str) -> None:
     if key == "SubSearch":
         key_type = SUBSEARCH_PATH
         value_name = ""
-        value = "SubSearch"
+        value = "Subsearch"
     if key.lower() == "icon":
         key_type = SUBSEARCH_PATH
         value_name = "Icon"
@@ -80,10 +80,10 @@ def get_command_value() -> str:
     Get the correct command value
     """
     # get latest json value from file
-    from utils import raw_config
+    from subsearch.utils import raw_config
 
     if current_user.check_is_exe():
-        value = f'"{sys.argv[0]}" %1'
+        value = f'"{sys.argv[0]}" "%1"'
         # if SubSearch is compiled we dont need anything besides this
     elif current_user.check_is_exe() is False:
         show_terminal = raw_config.get("show_terminal")
@@ -91,14 +91,14 @@ def get_command_value() -> str:
         python_path = os.path.dirname(sys.executable)
         # sys.args[-1] is going to be the path to the file we right clicked on
         # import_sys = "import sys; media_file_path = sys.argv[-1];"
-        set_title = "import ctypes; ctypes.windll.kernel32.SetConsoleTitleW('SubSearch');"
+        set_title = "import ctypes; ctypes.windll.kernel32.SetConsoleTitleW('Subsearch');"
         # gets the path of the root directory of subsearch
         set_wd = f"import os; os.chdir(r'{__root__}');"
         import_main = "import subsearch; subsearch.main()"
         if show_terminal is True:
-            value = f'{python_path}\python.exe -c "{set_title} {set_wd} {import_main}" %1'
+            value = f'{python_path}\python.exe -c "{set_title} {set_wd} {import_main}" "%1"'
         if show_terminal is False:
-            value = f'{python_path}\pythonw.exe -c "{set_title} {set_wd} {import_main}" %1'
+            value = f'{python_path}\pythonw.exe -c "{set_title} {set_wd} {import_main}" "%1"'
 
     return value
 
@@ -108,24 +108,23 @@ def get_icon_value() -> str:
     Check config.json cm_icon value
 
     """
-    from utils import raw_config
+    from subsearch.utils import raw_config
 
     show_icon: str = raw_config.get("cm_icon")
     icon_path = os.path.join(__icons__, "16.ico")
-    if show_icon is True:
-        value = icon_path
-    if show_icon is False:
-        value = ""
-    return value
+    if show_icon:
+        return icon_path
+    else:
+        return ""
 
 
 def get_appliesto_value() -> str:
     # get latest json value from file
-    from utils import raw_config
+    from subsearch.utils import raw_config
 
     file_ext = raw_config.get("file_ext")
     # for which file types to show the SubSearch context entry on
-    value = '"subsearch.py" OR '
+    value = '"__main__.py" OR '
     for k, v in zip(file_ext.keys(), file_ext.values()):
         if v is True:
             value += "".join(f'"{k}" OR ')
@@ -142,7 +141,7 @@ def remove_context_menu() -> None:
 
     with winreg.ConnectRegistry(COMPUTER_NAME, winreg.HKEY_CURRENT_USER) as hkey:
         with winreg.OpenKey(hkey, SHELL_PATH, 0, winreg.KEY_WRITE) as sk:
-            winreg.DeleteKey(sk, "0.SubSearch")
+            winreg.DeleteKey(sk, "0.Subsearch")
 
 
 # write keys to registry then write values
